This is a rust base and python logic project.

We use pyo3 to bradge rust and python.

This project is a rule-driven and powerful AI framework designed to support multimodal machine learning and cross-platform robot development.

We use ruff to format and lint code, we use .rst grammar to write the README.rst and all the docstring in English.
